@@ -4,15 +4,18 @@ import os
 import urllib.request
 import typing
 from typing import Any, Dict, List, Optional, Type
+import warnings
 
 from .annealing import AnnealingTask, AnnealingResult
 from .data import ExecutionRequest, ExecutionRequestEncoder, Status, TaskData, TaskListData
 from .device import Device
-from .task import Task, TaskIter, TaskList
+from .task import CloudTask, TaskIter, TaskList
+from .local import make_localtask
 
 from .datafactory import make_executiondata, make_result
 
 if typing.TYPE_CHECKING:
+    from .task import AbstractTask
     from blueqat import Circuit
 
 API_ENDPOINT = "https://cloudapi.blueqat.com/"
@@ -58,7 +61,7 @@ class Api:
         res = self.post_request(path, {"id": taskid})
         return Status(res['status'])
 
-    def post_executiondata(self, execdata: ExecutionRequest) -> Task:
+    def post_executiondata(self, execdata: ExecutionRequest) -> 'AbstractTask':
         """Create new task"""
         path = "v2/quantum-tasks/create"
         res = self.post_request(path,
@@ -67,7 +70,7 @@ class Api:
         taskdata = TaskData.from_dict(res['task'])
         result = make_result(res.get('result', {}),
                              Device(taskdata.device))
-        return Task(self, taskdata, result)
+        return CloudTask(self, taskdata, result)
 
     def annealing(self, qubo: List[List[float]], chain_strength: int,
                   num_reads: int) -> AnnealingResult:
@@ -85,8 +88,12 @@ class Api:
                 device: Device,
                 shots: int,
                 group: Optional[str] = None,
-                send_email: bool = False) -> Task:
+                send_email: bool = False) -> 'AbstractTask':
         """Create new task and execute the task."""
+        if device.value == 'local':
+            if group is not None or send_email:
+                warnings.warn('Arguments `group` and `send_email` is ignored in local device.')
+            return make_localtask(c, shots)
         execdata = make_executiondata(c, device, shots, group, send_email)
         return self.post_executiondata(execdata)
 
@@ -100,7 +107,7 @@ class Api:
         assert isinstance(tasks, list)
         return [AnnealingTask(self, **task) for task in tasks]
 
-    def task_result(self, task_id: str) -> Task:
+    def task_result(self, task_id: str) -> CloudTask:
         """Get a task and result from task ID."""
         path = "v2/quantum-tasks/get"
         body = {
@@ -110,7 +117,7 @@ class Api:
         taskdata = TaskData.from_dict(task_result['task'])
         result = make_result(task_result.get('result', {}),
                              Device(taskdata.device))
-        return Task(self, taskdata, result)
+        return CloudTask(self, taskdata, result)
 
     def tasks(self,
               group: Optional[str] = None,
